package boshclient

import (
	"fmt"
	"log"
	"net/http"
)

func (c *Client) GetTasks(deploymentName string, logger *log.Logger) (BoshTasks, error) {
	logger.Printf("getting tasks for deployment %s from bosh\n", deploymentName)
	return c.getTasks(deploymentName, "", logger)
}

func (c *Client) GetTasksByContext(deploymentName, contextID string, logger *log.Logger) (BoshTasks, error) {
	logger.Printf("getting tasks for deployment %s with context %s from bosh\n", deploymentName, contextID)
	return c.getTasks(deploymentName, contextID, logger)
}

func (c *Client) getTasks(deploymentName string, contextID string, logger *log.Logger) (BoshTasks, error) {
	url := fmt.Sprintf("%s/tasks?deployment=%s", c.boshURL, deploymentName)

	if contextID != "" {
		url = url + fmt.Sprintf("&context_id=%s", contextID)
	}

	var getTasksResponse BoshTasks

	if err := c.getDataFromBoshCheckingForErrors(
		fmt.Sprintf(url),
		http.StatusOK,
		&getTasksResponse,
		logger,
	); err != nil {
		return nil, err
	}

	return getTasksResponse, nil
}
